Documentation
¶
Index ¶
Constants ¶
const FullSnapshotMinutes = 10
const FullSnapshotsPerHour = 6
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Schedule ¶ added in v0.65.0
type Schedule struct {
// contains filtered or unexported fields
}
func (Schedule) ScheduleSecondary ¶ added in v0.65.0
func (schedule Schedule) ScheduleSecondary(ctx context.Context, primarySchedule Schedule, runner func(context.Context), logger *util.Logger, logName string)
ScheduleSecondary - Behaves almost like Schedule, but ignores the point in time where the primary schedule also has a run (to avoid overlapping statistics)
Click to show internal directories.
Click to hide internal directories.